abacusai.constants_autocomplete_response — AbacusAI documentation

# abacusai.constants_autocomplete_response

## Classes

`ConstantsAutocompleteResponse` | A dictionary of constants to be used in the autocomplete.

## Module Contents

class abacusai.constants_autocomplete_response.ConstantsAutocompleteResponse(client, maxPendingRequests=None, acceptanceDelay=None, debounceDelay=None, recordUserAction=None, validateSuggestion=None, validationLinesThreshold=None, maxTrackedRecentChanges=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A dictionary of constants to be used in the autocomplete.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - maxPendingRequests (int) – The maximum number of pending requests.

    - acceptanceDelay (int) – The acceptance delay.

    - debounceDelay (int) – The debounce delay.

    - recordUserAction (bool) – Whether to record user action.

    - validateSuggestion (bool) – Whether to validate the suggestion.

    - validationLinesThreshold (int) – The number of lines to validate the suggestion.

    - maxTrackedRecentChanges (int) – The maximum number of recent file changes to track.

  max_pending_requests = None
  acceptance_delay = None
  debounce_delay = None
  record_user_action = None
  validate_suggestion = None
  validation_lines_threshold = None
  max_tracked_recent_changes = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict